summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/bookmark_bar_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/views/bookmark_bar_view.h')
-rw-r--r--chrome/browser/views/bookmark_bar_view.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/chrome/browser/views/bookmark_bar_view.h b/chrome/browser/views/bookmark_bar_view.h
index 0726449..5947c60 100644
--- a/chrome/browser/views/bookmark_bar_view.h
+++ b/chrome/browser/views/bookmark_bar_view.h
@@ -90,6 +90,7 @@ class BookmarkBarView : public views::View,
// View methods:
virtual gfx::Size GetPreferredSize();
+ virtual gfx::Size GetMinimumSize();
virtual void Layout();
virtual void DidChangeBounds(const gfx::Rect& previous,
const gfx::Rect& current);
@@ -138,8 +139,9 @@ class BookmarkBarView : public views::View,
// True if we're on a page where the bookmarks bar is always visible.
bool OnNewTabPage();
- // How much we want the bookmark bar to overlap the toolbar.
- int GetToolbarOverlap();
+ // How much we want the bookmark bar to overlap the toolbar. If |return_max|
+ // is true, we return the maximum overlap rather than the current overlap.
+ int GetToolbarOverlap(bool return_max);
// Whether or not we are animating.
bool IsAnimating() { return size_animation_->IsAnimating(); }